@@ -68,6 +68,7 @@
 #include <xsh_rectify.h>
 #include <xsh_model_utils.h>
 
+#define new_bp 1
 /*#include <omp.h> */
 
 /*-----------------------------------------------------------------------------
@@ -238,17 +239,11 @@ xsh_rec_list_rectify( xsh_rec_list *rec_list, int iorder, int irec,
 
     /* Otherwise if kernel radius is greater than zero */
     else {
+
+#if new_bp
       double flux_val=0, confidence=0 ;
       check( flux_val = cpl_image_get_interpolated( sci_img, fx, fy,
               profile, radius, profile, radius, &confidence));
-      /* If error or undefined or pixel within kernel radius of edge */
-      if (confidence < 1) {
-        rec_flux[irec] = 0;
-        rec_errs[irec] = 1;
-        rec_qual[irec] = QFLAG_MISSING_DATA;
-
-      /* If flux interpolation ok */
-      } else {
 
         /* Now propagate errors */
         float err_val = 0;
@@ -267,9 +262,49 @@ xsh_rec_list_rectify( xsh_rec_list *rec_list, int iorder, int irec,
         /* Save the interpolated values */
         rec_flux[irec] = flux_val;
         rec_errs[irec] = sqrt(err_val);
-        rec_qual[irec] = qual_val;
+        if (confidence < 1) {
+            /* If error or undefined or pixel within kernel radius of edge */
+            rec_qual[irec] = qual_val || QFLAG_MISSING_DATA;
+        } else {
+            rec_qual[irec] = qual_val;
+        }
+
       }
+#else
+    double flux_val=0, confidence=0 ;
+    check( flux_val = cpl_image_get_interpolated( sci_img, fx, fy,
+            profile, radius, profile, radius, &confidence));
+    /* If error or undefined or pixel within kernel radius of edge */
+    if (confidence < 1) {
+      //rec_flux[irec] = 0;
+      rec_flux[irec] = flux_val;
+      rec_errs[irec] = 1;
+      rec_qual[irec] = QFLAG_MISSING_DATA;
+
+    /* If flux interpolation ok */
+    } else {
+
+      /* Now propagate errors */
+      float err_val = 0;
+      check( err_val = cpl_image_get_interpolated( var_img, fx, fy,
+        profile2, radius, profile2, radius, &confidence));
+
+      /* Now propagate flags */
+      int qual_val = 0;
+      for(j=yfirst;j<ylast-1;j++) {
+          j_nx=j*nx;
+          for(i=xfirst;i<xlast-1;i++) {
+              qual_val |= qual[j_nx+i];         //UMR
+          }
+      }
+
+      /* Save the interpolated values */
+      rec_flux[irec] = flux_val;
+      rec_errs[irec] = sqrt(err_val);
+      rec_qual[irec] = qual_val;
     }
+  }
+#endif
 
     /* This is to perform flux conservation via the Jacobian */
     rec_flux[irec] *= mult;
